This function computes the confidence interval (CI) of the sensitivity and specificity of the thresholds given in argument.
# ci.thresholds(...)
# S3 method for roc
ci.thresholds(roc, conf.level=0.95, boot.n=2000,
boot.stratified=TRUE, thresholds = "local maximas",
progress = NULL, parallel=FALSE, ...)
# S3 method for formula
ci.thresholds(formula, data, ...)
# S3 method for smooth.roc
ci.thresholds(smooth.roc, ...)
# S3 method for default
ci.thresholds(response, predictor, ...)A list of length 2 and class “ci.thresholds”, “ci” and “list” (in this order), with the confidence intervals of the CI and the following items:
a matrix of CI for the specificity. Row (names) are the thresholds, the first column the lower bound, the 2nd column the median and the 3rd column the upper bound.
same than specificity.
Additionally, the list has the following attributes:
the width of the CI, in fraction.
the number of bootstrap replicates.
whether or not the bootstrapping was stratified.
the thresholds, as given in argument.
the object of class “roc” that was used to compute the CI.
ci.thresholds.formula and ci.thresholds.default are convenience methods
that build the ROC curve (with the roc function) before
calling ci.thresholds.roc. You can pass them arguments for both
roc and ci.thresholds.roc. Simply use ci.thresholds
that will dispatch to the correct method.
This function creates boot.n bootstrap replicate of the ROC
curve, and evaluates the sensitivity and specificity at thresholds
given by the thresholds argument. Then it computes the
confidence interval as the percentiles given by conf.level.
A threshold given as a logical vector or character is converted to the corresponding numeric vector once
using the supplied ROC curve, and not at each bootstrap iteration. See ci.coords for the latter behaviour.
For more details about the bootstrap, see the Bootstrap section in this package's documentation.
James Carpenter and John Bithell (2000) ``Bootstrap condence intervals: when, which, what? A practical guide for medical statisticians''. Statistics in Medicine 19, 1141--1164. DOI: tools:::Rd_expr_doi("10.1002/(SICI)1097-0258(20000515)19:9<1141::aid-sim479>3.0.CO;2-F").1141::aid-sim479>
Tom Fawcett (2006) ``An introduction to ROC analysis''. Pattern Recognition Letters 27, 861--874. DOI: tools:::Rd_expr_doi("10.1016/j.patrec.2005.10.010").
Xavier Robin, Natacha Turck, Alexandre Hainard, et al. (2011) ``pROC: an open-source package for R and S+ to analyze and compare ROC curves''. BMC Bioinformatics, 7, 77. DOI: tools:::Rd_expr_doi("10.1186/1471-2105-12-77").
Hadley Wickham (2011) ``The Split-Apply-Combine Strategy for Data Analysis''. Journal of Statistical Software, 40, 1--29. URL: tools:::Rd_expr_doi("10.18637/jss.v040.i01").
roc,
ci